@@ -92,18 +92,6 @@ class TestSCSchemaDefinitions (TestCase):
         self.assertIsInstance(kSCValNetAirPortJoinModeRecent, unicode)
         self.assertIsInstance(kSCValNetAirPortJoinModeStrongest, unicode)
         self.assertIsInstance(kSCValNetAirPortAuthPasswordEncryptionKeychain, unicode)
-        self.assertIsInstance(kSCPropNetAppleTalkComputerName, unicode)
-        self.assertIsInstance(kSCPropNetAppleTalkComputerNameEncoding, unicode)
-        self.assertIsInstance(kSCPropNetAppleTalkConfigMethod, unicode)
-        self.assertIsInstance(kSCPropNetAppleTalkDefaultZone, unicode)
-        self.assertIsInstance(kSCPropNetAppleTalkNetworkID, unicode)
-        self.assertIsInstance(kSCPropNetAppleTalkNetworkRange, unicode)
-        self.assertIsInstance(kSCPropNetAppleTalkNodeID, unicode)
-        self.assertIsInstance(kSCPropNetAppleTalkSeedNetworkRange, unicode)
-        self.assertIsInstance(kSCPropNetAppleTalkSeedZones, unicode)
-        self.assertIsInstance(kSCValNetAppleTalkConfigMethodNode, unicode)
-        self.assertIsInstance(kSCValNetAppleTalkConfigMethodRouter, unicode)
-        self.assertIsInstance(kSCValNetAppleTalkConfigMethodSeedRouter, unicode)
         self.assertIsInstance(kSCPropNetDNSDomainName, unicode)
         self.assertIsInstance(kSCPropNetDNSOptions, unicode)
         self.assertIsInstance(kSCPropNetDNSSearchDomains, unicode)
@@ -173,14 +161,6 @@ class TestSCSchemaDefinitions (TestCase):
         self.assertIsInstance(kSCValNetModemDialModeIgnoreDialTone, unicode)
         self.assertIsInstance(kSCValNetModemDialModeManual, unicode)
         self.assertIsInstance(kSCValNetModemDialModeWaitForDialTone, unicode)
-        self.assertIsInstance(kSCPropNetNetInfoBindingMethods, unicode)
-        self.assertIsInstance(kSCPropNetNetInfoServerAddresses, unicode)
-        self.assertIsInstance(kSCPropNetNetInfoServerTags, unicode)
-        self.assertIsInstance(kSCPropNetNetInfoBroadcastServerTag, unicode)
-        self.assertIsInstance(kSCValNetNetInfoBindingMethodsBroadcast, unicode)
-        self.assertIsInstance(kSCValNetNetInfoBindingMethodsDHCP, unicode)
-        self.assertIsInstance(kSCValNetNetInfoBindingMethodsManual, unicode)
-        self.assertIsInstance(kSCValNetNetInfoDefaultServerTag, unicode)
         self.assertIsInstance(kSCPropNetPPPACSPEnabled, unicode)
         self.assertIsInstance(kSCPropNetPPPConnectTime, unicode)
         self.assertIsInstance(kSCPropNetPPPDeviceLastCause, unicode)
@@ -286,6 +266,29 @@ class TestSCSchemaDefinitions (TestCase):
         self.assertIsInstance(kSCPropUsersConsoleUserUID, unicode)
         self.assertIsInstance(kSCPropUsersConsoleUserGID, unicode)
 
+    @max_os_level('10.11')
+    def testConstantsUpto10_12(self):
+        self.assertIsInstance(kSCPropNetAppleTalkComputerName, unicode)
+        self.assertIsInstance(kSCPropNetAppleTalkComputerNameEncoding, unicode)
+        self.assertIsInstance(kSCPropNetAppleTalkConfigMethod, unicode)
+        self.assertIsInstance(kSCPropNetAppleTalkDefaultZone, unicode)
+        self.assertIsInstance(kSCPropNetAppleTalkNetworkID, unicode)
+        self.assertIsInstance(kSCPropNetAppleTalkNetworkRange, unicode)
+        self.assertIsInstance(kSCPropNetAppleTalkNodeID, unicode)
+        self.assertIsInstance(kSCPropNetAppleTalkSeedNetworkRange, unicode)
+        self.assertIsInstance(kSCPropNetAppleTalkSeedZones, unicode)
+        self.assertIsInstance(kSCValNetAppleTalkConfigMethodNode, unicode)
+        self.assertIsInstance(kSCValNetAppleTalkConfigMethodRouter, unicode)
+        self.assertIsInstance(kSCValNetAppleTalkConfigMethodSeedRouter, unicode)
+        self.assertIsInstance(kSCPropNetNetInfoBindingMethods, unicode)
+        self.assertIsInstance(kSCPropNetNetInfoServerAddresses, unicode)
+        self.assertIsInstance(kSCPropNetNetInfoServerTags, unicode)
+        self.assertIsInstance(kSCPropNetNetInfoBroadcastServerTag, unicode)
+        self.assertIsInstance(kSCValNetNetInfoBindingMethodsBroadcast, unicode)
+        self.assertIsInstance(kSCValNetNetInfoBindingMethodsDHCP, unicode)
+        self.assertIsInstance(kSCValNetNetInfoBindingMethodsManual, unicode)
+        self.assertIsInstance(kSCValNetNetInfoDefaultServerTag, unicode)
+
     @min_os_level('10.6')
     def testConstants10_6(self):
         self.assertIsInstance(kSCValNetInterfaceTypeIPSec, unicode)
